==> zio-aws-fsx_2.12-5.17.124.3-sources.jar: zio/aws/fsx/model/UpdateSvmActiveDirectoryConfiguration.scala <==
package zio.aws.fsx.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateSvmActiveDirectoryConfiguration(
    selfManagedActiveDirectoryConfiguration: Option[
      zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration = {
    import UpdateSvmActiveDirectoryConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration
      .builder()
      .optionallyWith(
        selfManagedActiveDirectoryConfiguration.map(value =>
          value.buildAwsValue()
        )
      )(_.selfManagedActiveDirectoryConfiguration)
      .build()
  }
  def asReadOnly
      : zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration.ReadOnly =
    zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration
      .wrap(buildAwsValue())
}
object UpdateSvmActiveDirectoryConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration =
      zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration(
        selfManagedActiveDirectoryConfiguration.map(value => value.asEditable)
      )
    def selfManagedActiveDirectoryConfiguration: Option[
      zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates.ReadOnly
    ]
    def getSelfManagedActiveDirectoryConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates.ReadOnly
    ] = AwsError.unwrapOptionField(
      "selfManagedActiveDirectoryConfiguration",
      selfManagedActiveDirectoryConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration
  ) extends zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration.ReadOnly {
    override val selfManagedActiveDirectoryConfiguration: Option[
      zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates.ReadOnly
    ] = scala
      .Option(impl.selfManagedActiveDirectoryConfiguration())
      .map(value =>
        zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration
  ): zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-fsx_2.13-5.17.164.1-sources.jar: zio/aws/fsx/model/UpdateSvmActiveDirectoryConfiguration.scala <==
package zio.aws.fsx.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateSvmActiveDirectoryConfiguration(
    selfManagedActiveDirectoryConfiguration: Optional[
      zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration = {
    import UpdateSvmActiveDirectoryConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration
      .builder()
      .optionallyWith(
        selfManagedActiveDirectoryConfiguration.map(value =>
          value.buildAwsValue()
        )
      )(_.selfManagedActiveDirectoryConfiguration)
      .build()
  }
  def asReadOnly
      : zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration.ReadOnly =
    zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration
      .wrap(buildAwsValue())
}
object UpdateSvmActiveDirectoryConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration =
      zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration(
        selfManagedActiveDirectoryConfiguration.map(value => value.asEditable)
      )
    def selfManagedActiveDirectoryConfiguration: Optional[
      zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates.ReadOnly
    ]
    def getSelfManagedActiveDirectoryConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates.ReadOnly
    ] = AwsError.unwrapOptionField(
      "selfManagedActiveDirectoryConfiguration",
      selfManagedActiveDirectoryConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration
  ) extends zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration.ReadOnly {
    override val selfManagedActiveDirectoryConfiguration: Optional[
      zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.selfManagedActiveDirectoryConfiguration())
      .map(value =>
        zio.aws.fsx.model.SelfManagedActiveDirectoryConfigurationUpdates
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.fsx.model.UpdateSvmActiveDirectoryConfiguration
  ): zio.aws.fsx.model.UpdateSvmActiveDirectoryConfiguration.ReadOnly =
    new Wrapper(impl)
}
